@@ -7,8 +7,11 @@
 #' @return Logical vector indicating which scripts were run.
 #'
 #' @note
-#' TAF scripts that will be run as needed: \verb{utilities.R}, \verb{data.R},
-#' \verb{model.R}, \verb{output.R}, and \verb{report.R}.
+#' TAF scripts that will be run as needed are: \verb{utilities.R},
+#' \verb{data.R}, \verb{model.R}, \verb{output.R}, and \verb{report.R}.
+#'
+#' The \verb{model.R} script may also be named \verb{method.R} and is treated in
+#' the same way.
 #'
 #' @seealso
 #' \code{\link{source}} runs any R script, \code{\link{source.taf}} is more
@@ -32,7 +35,7 @@
 
 make.all <- function(...)
 {
-  scripts <- c("utilities.R", "data.R", "model.R", "output.R", "report.R")
+  scripts <- c("utilities.R", "data.R", model.script(), "output.R", "report.R")
   scripts <- scripts[file.exists(scripts)]
 
   out <- sapply(scripts, make.taf, ...)
