@@ -7,9 +7,12 @@
 #' @return Logical vector, indicating which scripts ran without errors.
 #'
 #' @note
-#' TAF scripts that will be run if they exist: \verb{utilities.R},
+#' TAF scripts that will be run if they exist are: \verb{utilities.R},
 #' \verb{data.R}, \verb{model.R}, \verb{output.R}, and \verb{report.R}.
 #'
+#' The \verb{model.R} script may also be named \verb{method.R} and is treated in
+#' the same way.
+#'
 #' @seealso
 #' \code{\link{source.taf}} runs a TAF script.
 #'
@@ -30,7 +33,7 @@
 
 source.all <- function(...)
 {
-  scripts <- c("utilities.R", "data.R", "model.R", "output.R", "report.R")
+  scripts <- c("utilities.R", "data.R", model.script(), "output.R", "report.R")
   scripts <- scripts[file.exists(scripts)]
 
   out <- sapply(scripts, source.taf, ...)
